==> tecton-1.1.14.tar.gz: tecton-1.1.14/README.md <==
![logo](https://s3.us-west-2.amazonaws.com/tecton.ai.public/documentation/pypi/tecton-logo.svg)

Tecton is the fastest way to build operational machine learning applications. It helps automate real-time decision making like fraud detection, product recommendations, and search result ranking in production applications.

Tecton is a fully-managed feature platform built to orchestrate the complete lifecycle of features, from transformation to online serving, with enterprise-grade SLAs.

With Tecton, you can:

- Define and manage features using code in a git repository.
- Automatically compute and orchestrate batch, streaming, and real-time feature
  transformations.
- Store and serve feature data for training and inference.
- Share, discover, and manage access to features.

# Contents of the `tecton` PyPI package

The `tecton` PyPI package bundles Tecton's Python SDK, which is used for defining and testing feature pipelines and services, and generating datasets for training and batch inference. For more information, see the [SDK reference](https://docs.tecton.ai/api-reference/index.html).

# Getting started resources

To get started using Tecton, see these resources, which are found in the [documentation](https://docs.tecton.ai/):

* [Machine Learning Application Concepts](https://docs.tecton.ai/docs/introduction/machine-learning-application-concepts)

* [Tecton Concepts](https://docs.tecton.ai/docs/introduction/tecton-concepts)

* [Setting up Tecton](https://docs.tecton.ai/docs/category/setting-up-tecton)

* [Tecton Fundamentals Tutorial](https://docs.tecton.ai/docs/tutorials/tecton-fundamentals/)

# License

Copyright (2023) Tecton, Inc. This library (the "Software") may not be used except in connection with the Licensee's use
of the Tecton Platform Services (defined below) pursuant to an Agreement (defined below) between Licensee (defined
below) and Tecton, Inc. ("Tecton"). This Software shall be deemed part of the "Services" under the Agreement, or if the
Agreement does not define Services, then the term in such Agreement that refers to the applicable Tecton Platform
Services (as defined below) shall be substituted herein for "Services." Licensee's use of the Software must comply at
all times with any restrictions applicable to the Services, generally, and must be used in accordance with any
applicable documentation. If you have not agreed to an Agreement or otherwise do not agree to these terms, you may not
use the Software. This license terminates automatically upon the termination of the Agreement or Licensee's breach of
these terms. Agreement: the agreement between Tecton and Licensee governing the use of the Tecton Platform Services,
which shall be, with respect to Tecton, the Tecton Platform-as-a-Service Agreement located
at https://www.tecton.ai/tecton_online-tos/, unless Licensee has entered into a separate written agreement with Tecton
governing the use of the Tecton Platform Services. Tecton Platform Services: the Tecton services according to where the
Software is used. Licensee: the user of the Software, or, if the Software is being used on behalf of a company, the
company.

==> tecton-1.2.11.tar.gz: tecton-1.2.11/README.md <==
![logo](https://s3.us-west-2.amazonaws.com/tecton.ai.public/documentation/pypi/tecton-logo.svg)

Tecton is the fastest way to build operational machine learning applications. It helps automate real-time decision making like fraud detection, product recommendations, and search result ranking in production applications.

Tecton is a fully-managed feature platform built to orchestrate the complete lifecycle of features, from transformation to online serving, with enterprise-grade SLAs.

With Tecton, you can:

- Define and manage features using code in a git repository.
- Automatically compute and orchestrate batch, streaming, and real-time feature
  transformations.
- Store and serve feature data for training and inference.
- Share, discover, and manage access to features.

# Contents of the `tecton` PyPI package

The `tecton` PyPI package bundles Tecton's Python SDK, which is used for defining and testing feature pipelines and services, and generating datasets for training and batch inference. For more information, see the [SDK reference](https://docs.tecton.ai/api-reference/index.html) and the [Tecton documentation](https://docs.tecton.ai/).

# License

Copyright (2025) Tecton, Inc. This library (the "Software") may not be used except in connection with the Licensee's use
of the Tecton Platform Services (defined below) pursuant to an Agreement (defined below) between Licensee (defined
below) and Tecton, Inc. ("Tecton"). This Software shall be deemed part of the "Services" under the Agreement, or if the
Agreement does not define Services, then the term in such Agreement that refers to the applicable Tecton Platform
Services (as defined below) shall be substituted herein for "Services." Licensee's use of the Software must comply at
all times with any restrictions applicable to the Services, generally, and must be used in accordance with any
applicable documentation. If you have not agreed to an Agreement or otherwise do not agree to these terms, you may not
use the Software. This license terminates automatically upon the termination of the Agreement or Licensee's breach of
these terms. Agreement: the agreement between Tecton and Licensee governing the use of the Tecton Platform Services,
which shall be, with respect to Tecton, the Tecton Platform-as-a-Service Agreement located
at https://www.tecton.ai/tecton_online-tos/, unless Licensee has entered into a separate written agreement with Tecton
governing the use of the Tecton Platform Services. Tecton Platform Services: the Tecton services according to where the
Software is used. Licensee: the user of the Software, or, if the Software is being used on behalf of a company, the
company.
